from setuptools import setup

setup(
	name = "Check_If_Prime",
	version = "1.1",
	description = "returns true if the integer is prime else false",
	author = "Panas Tiwari",
	author_email = "panas.tiwary18@gmail.com",
	packages = ["Check_If_Prime"],
	url = "https://github.com/panas18/check_prime",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)




def check_prime(num) -> bool:
    """checks whether the given number is prime or not

    Args:
                    num (int): positive integer

    Returns:
                    bool: True if num is prime else False
    """
    
    if num > 1:
        for i in range(2, num):
            if (num % i) == 0:
                return False
    elif num < 0:
        raise ValueError("Number must be a positive  integer")

    return True
